@@ -79,10 +79,8 @@ class Completion:
             "max_tokens": 256,
             "temperature": 0.7,
             "top_p": 1,
-            "n": 1,
             "suffix": None,
             "stop": None,
-            "best_of": 1,
             "stream": False,
             "logprobs": 5,
             "presence_penalty": 0.0,
